==> julia-git-modelingtoolkit-src-9.54.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/ModelingToolkit/docs/pages.jl <==
pages = [
    "Home" => "index.md",
    "tutorials/ode_modeling.md",
    "Tutorials" => Any["tutorials/acausal_components.md",
        "tutorials/nonlinear.md",
        "tutorials/initialization.md",
        "tutorials/optimization.md",
        "tutorials/modelingtoolkitize.md",
        "tutorials/programmatically_generating.md",
        "tutorials/stochastic_diffeq.md",
        "tutorials/discrete_system.md",
        "tutorials/parameter_identifiability.md",
        "tutorials/bifurcation_diagram_computation.md",
        "tutorials/SampledData.md",
        "tutorials/domain_connections.md",
        "tutorials/callable_params.md"],
    "Examples" => Any[
        "Basic Examples" => Any["examples/higher_order.md",
            "examples/spring_mass.md",
            "examples/modelingtoolkitize_index_reduction.md",
            "examples/remake.md"],
        "Advanced Examples" => Any["examples/tearing_parallelism.md",
            "examples/sparse_jacobians.md",
            "examples/perturbation.md"]],
    "Basics" => Any["basics/AbstractSystem.md",
        "basics/ContextualVariables.md",
        "basics/Variable_metadata.md",
        "basics/Composition.md",
        "basics/Events.md",
        "basics/Linearization.md",
        "basics/InputOutput.md",
        "basics/MTKLanguage.md",
        "basics/Validation.md",
        "basics/DependencyGraphs.md",
        "basics/Precompilation.md",
        "basics/FAQ.md"],
    "System Types" => Any["systems/ODESystem.md",
        "systems/SDESystem.md",
        "systems/JumpSystem.md",
        "systems/NonlinearSystem.md",
        "systems/OptimizationSystem.md",
        "systems/PDESystem.md"],
    "comparison.md",
    "internals.md"
]

==> julia-git-modelingtoolkit-src-9.64.3-1-any.pkg.tar.zst: usr/share/julia/arch-site/ModelingToolkit/docs/pages.jl <==
pages = [
    "Home" => "index.md",
    "tutorials/ode_modeling.md",
    "Tutorials" => Any["tutorials/acausal_components.md",
        "tutorials/nonlinear.md",
        "tutorials/initialization.md",
        "tutorials/optimization.md",
        "tutorials/modelingtoolkitize.md",
        "tutorials/programmatically_generating.md",
        "tutorials/stochastic_diffeq.md",
        "tutorials/discrete_system.md",
        "tutorials/parameter_identifiability.md",
        "tutorials/bifurcation_diagram_computation.md",
        "tutorials/SampledData.md",
        "tutorials/domain_connections.md",
        "tutorials/callable_params.md",
        "tutorials/linear_analysis.md"],
    "Examples" => Any[
        "Basic Examples" => Any["examples/higher_order.md",
            "examples/spring_mass.md",
            "examples/modelingtoolkitize_index_reduction.md",
            "examples/remake.md"],
        "Advanced Examples" => Any["examples/tearing_parallelism.md",
            "examples/sparse_jacobians.md",
            "examples/perturbation.md"]],
    "Basics" => Any["basics/AbstractSystem.md",
        "basics/ContextualVariables.md",
        "basics/Variable_metadata.md",
        "basics/Composition.md",
        "basics/Events.md",
        "basics/Linearization.md",
        "basics/InputOutput.md",
        "basics/MTKLanguage.md",
        "basics/Validation.md",
        "basics/Debugging.md",
        "basics/DependencyGraphs.md",
        "basics/Precompilation.md",
        "basics/FAQ.md"],
    "System Types" => Any["systems/ODESystem.md",
        "systems/SDESystem.md",
        "systems/JumpSystem.md",
        "systems/NonlinearSystem.md",
        "systems/OptimizationSystem.md",
        "systems/PDESystem.md",
        "systems/DiscreteSystem.md"],
    "comparison.md",
    "internals.md"
]
